@@ -38,7 +38,7 @@ class ImageStream(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({
                 "spec": {
                     "lookupPolicy": {"local": self.lookup_policy},
