@@ -37,7 +37,7 @@ class PodDisruptionBudget(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             update_dict = {
                 "spec": {
                     "selector": self.selector,
