@@ -52,5 +52,5 @@ class Role(NamespacedResource):
             raise MissingRequiredArgumentError(argument="rules")
         if not self.res:
             super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res["rules"] = self.rules
