@@ -51,7 +51,7 @@ class VirtualMachineExport(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not (self.source_kind and self.source_name):
                 raise MissingRequiredArgumentError(argument="'source_kind' and 'source_name'")
             self.res.update({
